@@ -3,9 +3,13 @@ from __future__ import division
 from __future__ import print_function
 
 import matplotlib
-matplotlib.use('Agg')
+if not matplotlib.rcParams.get('backend', None):
+    matplotlib.use('Agg')
+
+from .ops import plot, plot_many
+from .wrapper import wrap, wrap_axesplot
+from .wrapper import autowrap
 
-from .ops import plot, plot_many, wrap, wrap_axesplot
 from .figure import subplots
 from . import summary
 
@@ -13,4 +17,4 @@ from matplotlib.figure import Figure
 from matplotlib.axes import Axes
 
 
-__version__ = '0.2.0'
+__version__ = '0.3.0'
